@@ -2,34 +2,13 @@ import re
 import sys
 import platform
 
-from .device_db import GPU_DEVICES
+from .gpu_db import get_nvidia_arch, get_amd_gfx_info
 from .consts import AMD, INTEL, NVIDIA, CONTACT_LINK
 
 os_name = platform.system()
 arch = platform.machine().lower()
 py_version = sys.version_info
 
-# https://www.techpowerup.com/gpu-specs/?architecture=Kepler&sort=generation and so on (change the arch field)
-KEPLER_DEVICES = re.compile(r"\b(gk1\d{2}\w*)\b", re.IGNORECASE)  # sm3.7
-MAXWELL_DEVICES = re.compile(r"\b(gm10\d\w*)\b", re.IGNORECASE)  # sm5
-PASCAL_DEVICES = re.compile(r"\b(gp10\d\w*)\b", re.IGNORECASE)  # sm6
-VOLTA_DEVICES = re.compile(r"\b(gv100\w*)\b", re.IGNORECASE)  # sm7
-TURING_DEVICES = re.compile(r"\b(tu1\d{2}\w*)\b", re.IGNORECASE)  # sm7.5
-AMPERE_DEVICES = re.compile(r"\b(ga10\d\w*)\b", re.IGNORECASE)  # sm8.6
-ADA_LOVELACE_DEVICES = re.compile(r"\b(ad10\d\w*)\b", re.IGNORECASE)  # sm8.9
-BLACKWELL_DEVICES = re.compile(r"\b(?:5060|5070|5080|5090)\b", re.IGNORECASE)  # sm10, sm12
-
-NVIDIA_ARCH_MAP = {
-    BLACKWELL_DEVICES: 12,
-    ADA_LOVELACE_DEVICES: 8.9,
-    AMPERE_DEVICES: 8.6,
-    TURING_DEVICES: 7.5,
-    VOLTA_DEVICES: 7,
-    PASCAL_DEVICES: 6,
-    MAXWELL_DEVICES: 5,
-    KEPLER_DEVICES: 3.7,
-}
-
 
 def get_torch_platform(gpu_infos):
     """
@@ -98,6 +77,12 @@ def _get_platform_for_discrete(gpu_infos):
             return "directml"
         elif os_name == "Linux":
             device_names = set(gpu.device_name for gpu in gpu_infos)
+            if any(device_name.startswith("Navi 4") for device_name in device_names):
+                if py_version < (3, 9):
+                    raise NotImplementedError(
+                        f"Torch does not support Navi 4x series of GPUs on Python 3.8. Please switch to a newer Python version to use the latest version of torch!"
+                    )
+                return "rocm6.4"
             if any(device_name.startswith("Navi") for device_name in device_names) and any(
                 device_name.startswith("Vega 2") for device_name in device_names
             ):  # lowest-common denominator is rocm5.7, which works with both Navi and Vega 20
@@ -171,14 +156,6 @@ def _get_platform_for_discrete(gpu_infos):
     return "cpu"
 
 
-def get_nvidia_arch(device_names):
-    for arch_regex, arch in NVIDIA_ARCH_MAP.items():
-        if any(arch_regex.search(device_name) for device_name in device_names):
-            return arch
-
-    return 0
-
-
 def _get_platform_for_integrated(gpu_infos):
     gpu = gpu_infos[0]
 
@@ -186,9 +163,7 @@ def _get_platform_for_integrated(gpu_infos):
         return "directml"
     elif os_name == "Linux":
         if gpu.vendor_id == AMD:
-            integrated_amd_gpus = GPU_DEVICES[AMD]["integrated"]
-
-            family_name, gfx_id, hsa_version = integrated_amd_gpus.get(gpu.device_id, ("", "", ""))
+            family_name, gfx_id, hsa_version = get_amd_gfx_info(gpu.device_id)
             if gfx_id.startswith("gfx11") or gfx_id.startswith("gfx103"):
                 if py_version < (3, 9):
                     print(
