@@ -28,6 +28,17 @@ def test_amd_gpu_windows(monkeypatch):
     assert get_torch_platform(gpu_infos) == "directml"
 
 
+def test_amd_gpu_navi4_linux(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Linux")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "x86_64")
+    gpu_infos = [GPU(AMD, "AMD", 0x1234, "Navi 41", True)]
+    if py_version < (3, 9):
+        with pytest.raises(NotImplementedError):
+            get_torch_platform(gpu_infos)
+    else:
+        assert get_torch_platform(gpu_infos) == "rocm6.4"
+
+
 def test_amd_gpu_navi3_linux(monkeypatch, capsys):
     monkeypatch.setattr("torchruntime.platform_detection.os_name", "Linux")
     monkeypatch.setattr("torchruntime.platform_detection.arch", "x86_64")
@@ -98,14 +109,16 @@ def test_nvidia_gpu_windows(monkeypatch):
     monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
     monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
     gpu_infos = [GPU(NVIDIA, "NVIDIA", 0x1234, "GeForce", True)]
-    assert get_torch_platform(gpu_infos) == "cu124"
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
 
 
 def test_nvidia_gpu_linux(monkeypatch):
     monkeypatch.setattr("torchruntime.platform_detection.os_name", "Linux")
     monkeypatch.setattr("torchruntime.platform_detection.arch", "x86_64")
     gpu_infos = [GPU(NVIDIA, "NVIDIA", 0x1234, "GeForce", True)]
-    assert get_torch_platform(gpu_infos) == "cu124"
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
 
 
 def test_nvidia_gpu_mac(monkeypatch):
@@ -116,6 +129,63 @@ def test_nvidia_gpu_mac(monkeypatch):
         get_torch_platform(gpu_infos)
 
 
+def test_nvidia_7xx_gpu_windows(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "1004", "GK110 [GeForce GTX 780]", True)]
+    assert get_torch_platform(gpu_infos) == "cu118"
+
+
+def test_nvidia_10xx_gpu_windows(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "1c02", "GP106 [GeForce GTX 1060 3GB]", True)]
+    assert get_torch_platform(gpu_infos) == "cu124"
+
+
+def test_nvidia_16xx_gpu_windows(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "21c4", "TU116 [GeForce GTX 1660 SUPER]", True)]
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
+
+
+def test_nvidia_20xx_gpu_windows(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "1f11", "TU106M [GeForce RTX 2060 Mobile]", True)]
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
+
+
+def test_nvidia_30xx_gpu_windows(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "2489", "GA104 [GeForce RTX 3060 Ti Lite Hash Rate]", True)]
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
+
+
+def test_nvidia_40xx_gpu_windows(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "2705", "AD103 [GeForce RTX 4070 Ti SUPER]", True)]
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
+
+
+def test_nvidia_5xxx_gpu_windows(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "2c02", "GB203 [GeForce RTX 5080]", True)]
+    if py_version < (3, 9):
+        with pytest.raises(NotImplementedError):
+            get_torch_platform(gpu_infos)
+    else:
+        assert get_torch_platform(gpu_infos) == "cu128"
+
+
 def test_intel_gpu_windows(monkeypatch):
     monkeypatch.setattr("torchruntime.platform_detection.os_name", "Windows")
     monkeypatch.setattr("torchruntime.platform_detection.arch", "amd64")
@@ -132,6 +202,17 @@ def test_intel_gpu_linux(monkeypatch):
     assert get_torch_platform(gpu_infos) == expected
 
 
+def test_nvidia_5xxx_gpu_linux(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Linux")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "x86_64")
+    gpu_infos = [GPU(NVIDIA, "NVIDIA", "2c02", "GB203 [GeForce RTX 5080]", True)]
+    if py_version < (3, 9):
+        with pytest.raises(NotImplementedError):
+            get_torch_platform(gpu_infos)
+    else:
+        assert get_torch_platform(gpu_infos) == "cu128"
+
+
 def test_intel_gpu_mac(monkeypatch):
     monkeypatch.setattr("torchruntime.platform_detection.os_name", "Darwin")
     monkeypatch.setattr("torchruntime.platform_detection.arch", "arm64")
@@ -147,7 +228,8 @@ def test_multiple_gpu_vendors_with_NVIDIA(monkeypatch):
         GPU(AMD, "AMD", 0x1234, "Radeon", True),
         GPU(NVIDIA, "NVIDIA", 0x5678, "GeForce", True),
     ]
-    assert get_torch_platform(gpu_infos) == "cu124"
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
 
 
 def test_multiple_gpu_vendors_without_NVIDIA(monkeypatch):
@@ -168,7 +250,19 @@ def test_multiple_gpu_NVIDIA(monkeypatch):
         GPU(NVIDIA, "NVIDIA", "2504", "GA106 [GeForce RTX 3060 Lite Hash Rate]", True),
         GPU(NVIDIA, "NVIDIA", "1c02", "GP106 [GeForce GTX 1060 3GB]", True),
     ]
-    assert get_torch_platform(gpu_infos) == "cu124"
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
+
+
+def test_multiple_gpu_NVIDIA_maxwell(monkeypatch):
+    monkeypatch.setattr("torchruntime.platform_detection.os_name", "Linux")
+    monkeypatch.setattr("torchruntime.platform_detection.arch", "x86_64")
+    gpu_infos = [
+        GPU(NVIDIA, "NVIDIA", "17fd", "GM200GL [Tesla M40]", True),
+        GPU(NVIDIA, "NVIDIA", "1401", "GM206 [GeForce GTX 960]", True),
+    ]
+    expected = "cu124"
+    assert get_torch_platform(gpu_infos) == expected
 
 
 def test_multiple_gpu_AMD_Navi3_Navi2(monkeypatch, capsys):
@@ -351,7 +445,8 @@ def test_mixed_nvidia_discrete_amd_integrated_linux(monkeypatch):
         GPU(AMD, "AMD", "164f", "Phoenix", False),  # integrated
         GPU(NVIDIA, "NVIDIA", "2504", "RTX 3060", True),  # discrete
     ]
-    assert get_torch_platform(gpu_infos) == "cu124"
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
 
 
 def test_mixed_nvidia_discrete_intel_integrated_windows(monkeypatch):
@@ -361,7 +456,8 @@ def test_mixed_nvidia_discrete_intel_integrated_windows(monkeypatch):
         GPU(INTEL, "Intel", "0x56c1", "UHD Graphics", False),  # integrated
         GPU(NVIDIA, "NVIDIA", "2504", "RTX 3060", True),  # discrete
     ]
-    assert get_torch_platform(gpu_infos) == "cu124"
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
 
 
 def test_mixed_amd_discrete_intel_integrated_linux(monkeypatch, capsys):
@@ -386,4 +482,5 @@ def test_mixed_multiple_discrete_and_integrated(monkeypatch):
         GPU(NVIDIA, "NVIDIA", "2504", "RTX 3060", True),  # discrete NVIDIA
         GPU(AMD, "AMD", "73f0", "Navi 33", True),  # discrete AMD
     ]
-    assert get_torch_platform(gpu_infos) == "cu124"
+    expected = "cu124" if py_version < (3, 9) else "cu128"
+    assert get_torch_platform(gpu_infos) == expected
